@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2017 ~ 2019 Uniontech Technology Co., Ltd.
- *
- * Author:     WangPeng <wangpenga@uniontech.com>
- *
- * Maintainer: AlexOne  <993381@qq.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2022 Uniontech Software Technology Co.,Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include "dnotitlebarwindowhelper_wl.h"
 #include "vtablehook.h"
 
@@ -122,6 +106,16 @@ void DNoTitlebarWlWindowHelper::setWindowProperty(QWindow *window, const char *n
     }
 }
 
+void DNoTitlebarWlWindowHelper::requestByWindowProperty(QWindow *window, const char *name)
+{
+    if (window && window->handle()) {
+        QtWaylandClient::QWaylandWindow *wl_window = static_cast<QtWaylandClient::QWaylandWindow *>(window->handle());
+
+        if (wl_window && wl_window->shellSurface())
+            wl_window->sendProperty(name, QVariant());
+    }
+}
+
 void DNoTitlebarWlWindowHelper::popupSystemWindowMenu(quintptr wid)
 {
     QWindow *window = fromQtWinId(wid);
