@@ -17,6 +17,7 @@
 #include "QtWaylandClient/private/qwaylandscreen_p.h"
 #undef private
 
+#ifndef D_DEEPIN_IS_DWAYLAND
 #include <KWayland/Client/registry.h>
 #include <KWayland/Client/plasmashell.h>
 #include <KWayland/Client/server_decoration.h>
@@ -29,6 +30,20 @@
 #include <KWayland/Client/blur.h>
 #include <KWayland/Client/region.h>
 #include <KWayland/Client/surface.h>
+#else
+#include <DWayland/Client/registry.h>
+#include <DWayland/Client/plasmashell.h>
+#include <DWayland/Client/server_decoration.h>
+#include <DWayland/Client/ddeshell.h>
+#include <DWayland/Client/ddeseat.h>
+#include <DWayland/Client/ddekeyboard.h>
+#include <DWayland/Client/strut.h>
+#include <DWayland/Client/fakeinput.h>
+#include <DWayland/Client/compositor.h>
+#include <DWayland/Client/blur.h>
+#include <DWayland/Client/region.h>
+#include <DWayland/Client/surface.h>
+#endif
 
 #include <QGuiApplication>
 #include <QPointer>
